<?php
/**
    @file
    @brief Script permettant de récupérer des données et les afficher au format JSON
    @author Julien George
*/

include_once('/usr/local/esia/public_html/plugin/virtualization/drivers/manifest.php');
$EXEC_PATH = '/usr/local/esia/public_html/plugin/virtualization/drivers';
$RESOURCES = explode(',','cluster,host,storage,vm,template,volume,snapshot');

function exit_error($message){
    echo "ERROR : ";
    echo trim($message);
    echo "\n";
    exit(1);
}

//Vérification des paramètres
//Paramètre authfile
if( empty($argv[1] ) )  { exit_error("You must specify authfile file"); }
$o_authfilepath = $argv['1'];


/*
if( stripos($o_authfilepath,'xen')){
    $drv_name = 'xenserver';
}
else if( stripos($o_authfilepath,'proxmox')){
    $drv_name = 'proxmox';
}
else { exit_error("Unable to identify driver name"); }
*/

if(  !is_readable($o_authfilepath) )    { exit_error("Unable to access to authfile : $o_authfilepath"); }

//Paramètre resources
if( !isset($argv[2]) ){
    echo "ERROR : ";
    echo "You must specify a resource :\n";
    foreach($RESOURCES as $resource){
        echo "- $resource\n";
    }
    exit(1);
}

$o_resource = $argv[2];
if( !in_array($o_resource,$RESOURCES))  exit_error("Unknown resource type $o_resource. Resource must be one of this (".implode(',',$RESOURCES).').');

$settings = file_get_contents($o_authfilepath);
$settings = json_decode($settings,TRUE);
$drv_name = $settings['driver'];

//Chargement du driveur
$drivers = getDriversForInstantiate();

$oldpath = get_include_path();
set_include_path($EXEC_PATH);
include_once($drivers[$drv_name]['file']);
set_include_path($oldpath);

if( $settings == FALSE )  { exit_error("Unable to parse json from authfile : $o_authfilepath"); }

$className = $drivers[$drv_name]['class'];
$clusterClass = new $className($settings);

$human_readeable = TRUE;

if( $o_resource == 'cluster' ){
    $data = $clusterClass->toArray(TRUE,FALSE,$human_readeable);
}
elseif( $o_resource == 'host'){
    foreach($clusterClass->getHosts() as $row){
	$data[]=$row->toArray(TRUE,FALSE,$human_readeable);
    }
}
elseif( $o_resource == 'vm'){
    foreach($clusterClass->getVMs() as $row){
	$data[]=$row->toArray(FALSE,FALSE,$human_readeable);
    }
}
elseif( $o_resource == 'template'){
    foreach($clusterClass->getTemplates() as $row){
	$data[]=$row;
    }
}
elseif( $o_resource == 'storage'){
    foreach($clusterClass->getStorages() as $row){
	$data[]=$row->toArray(FALSE,FALSE,$human_readeable);
    }
}
elseif( $o_resource == 'volume'){
    if( !isset($argv[3]) ){
        echo "ERROR : ";
        echo "You must specify a parent ID for this ressource :\n";
        echo "#STORAGES\n";
        foreach($clusterClass->getStorages() as $row){
            $name = $row->getName();
            $id = $row->getId();
            echo "ID=SR:$id\n";
            echo "NAME=$name\n";
            echo "\n";
        }
        echo "\n";
        echo "#VM\n";
        foreach($clusterClass->getVMs() as $row){
            $name = $row->getName();
            $id = $row->getId();
            echo "ID=VM:$id\n";
            echo "NAME=$name\n";
            echo "\n";
        }
        exit(1);
    }

    $volume = $argv[3];
    $volume_id = explode(':',$volume,2);
    $data = array();
    if($volume_id[0] == 'SR')
    {
        $storages = $clusterClass->getStorages();
        foreach($storages as $storage)
        {
            if($storage->getId() == $volume_id[1])
            {
                $data = $storage->getVolumes();
                break;
            }
        }
        if( empty($data) )
        {
            echo "ERROR : ";
            echo "Storage not found\n";
            exit(1);
        }
    }
    elseif($volume_id[0] == 'VM')
    {
        $vm = $clusterClass->getVM($volume_id[1]);
        if( empty($vm) )
        {
            echo "ERROR : ";
            echo "VM not found\n";
            exit(1);
        }
        $data = $vm->getVolumes();
    }
    else
    {
        echo "ERROR : ";
        echo "Parent resource id must be preceded with VM: or STORAGE:\n";
        exit(1);
    }
}
elseif( $o_resource == 'snapshot'){
    if( !isset($argv[3]) ){
        echo "ERROR : ";
        echo "You must specify a parent ID for this ressource :\n";
        echo "#VM\n";
        foreach($clusterClass->getVMs() as $row){
            $name = $row->getName();
            $id = $row->getId();
            echo "ID=VM:$id\n";
            echo "NAME=$name\n";
            echo "\n";
        }
        exit(1);
    }

    $volume = $argv[3];
    $volume_id = explode(':',$volume,2);
    if($volume_id[0] == 'VM')
    {
        $vm = $clusterClass->getVM($volume_id[1]);
        if( empty($vm) )
        {
            echo "ERROR : ";
            echo "VM not found\n";
            exit(1);
        }
        $data = $vm->getSnapshots();
    }
    else
    {
        echo "ERROR : ";
        echo "Parent resource id must be preceded with VM:\n";
        exit(1);
    }
}

//print_r($data);
echo json_encode($data,JSON_PRETTY_PRINT)."\n";

exit(0);
